@@ -1,8 +1,8 @@
-use crate::model::transition::Transition;
+use crate::core::transition::Transition;
 
 #[test]
 pub fn should_compare_partially() {
-    let transition = Transition { event: "EVENT".to_string(), state_in: "INPUT".to_string(), state_out: "OUTPUT".to_string() };
+    let transition = Transition::new("INPUT".to_string(), "EVENT".to_string(), "OUTPUT".to_string());
     
     assert!(transition.partial_compare(None, None, None));
     assert!(transition.partial_compare(None, None, Some(&"OUTPUT".to_string())));
@@ -16,4 +16,20 @@ pub fn should_compare_partially() {
     assert!(!transition.partial_compare(None, None, Some(&"OTHER".to_string())));
     assert!(!transition.partial_compare(None, Some(&"OTHER".to_string()), None));
     assert!(!transition.partial_compare(Some(&"OTHER".to_string()), None, None));
+}
+
+#[test]
+pub fn should_allow_without_guard() {
+    let transition = Transition::new("INPUT".to_string(), "EVENT".to_string(), "OUTPUT".to_string());
+    assert!(transition.is_allowed());
+}
+
+#[test]
+pub fn should_guard() {
+    let mut transition = Transition::new("INPUT".to_string(), "EVENT".to_string(), "OUTPUT".to_string());
+    transition.guard = Some(|| true);
+    assert!(transition.is_allowed());
+
+    transition.guard = Some(|| false);
+    assert!(!transition.is_allowed());
 }
\ No newline at end of file
