@@ -1,15 +1,15 @@
 use crate::core::transitionable::Transitionable;
 
-pub struct DummyTransitionable {
-    pub state: String,
+pub struct DummyTransitionable<'dt> {
+    pub state: &'dt str,
 }
 
-impl Transitionable for DummyTransitionable {
-    fn get_state(&self) -> String {
-        self.state.to_string()
+impl<'dt> Transitionable<&'dt str> for DummyTransitionable<'dt> {
+    fn get_state(&self) -> &'dt str {
+        self.state
     }
 
-    fn set_state(&mut self, new_state: String) {
+    fn set_state(&mut self, new_state: &'dt str) {
         self.state = new_state;   
     }
 }
@@ -17,7 +17,7 @@ impl Transitionable for DummyTransitionable {
 #[test]
 fn should_get_state() {
     let state = "INPUT";
-    let transitionable = DummyTransitionable{ state: state.to_string() };
+    let transitionable = DummyTransitionable{ state };
     assert_eq!(state.to_string(), transitionable.get_state());
 }
 
@@ -25,9 +25,9 @@ fn should_get_state() {
 fn should_set_state() {
     let state_before = "INPUT";
     let state_after  = "OUTPUT";
-    let mut transitionable = DummyTransitionable{ state: state_before.to_string() };
+    let mut transitionable = DummyTransitionable{ state: state_before };
 
     assert_eq!(state_before.to_string(), transitionable.get_state());
-    transitionable.set_state(state_after.to_string());
+    transitionable.set_state(state_after);
     assert_eq!(state_after.to_string(), transitionable.get_state());
 }
\ No newline at end of file
